@@ -1,5 +1,6 @@
 from collections import OrderedDict
 import json
+import warnings
 
 from ..core import AtlasEntity, AtlasProcess
 from . import util as reader_util
@@ -199,7 +200,7 @@ class LineageMixIn():
             `:class:~pyapacheatlas.core.entity.AtlasEntity`
         """
         _qual_name = reader_util._make_col_qual_name(
-            row[headers["column"]], parent_table_entity.get_name())
+            row[headers["column"]], parent_table_entity.name)
 
         _clean_attribs = reader_util.columns_matching_pattern(
             row, prefix,
@@ -237,7 +238,7 @@ class LineageMixIn():
             popped_entity = column_entities.pop(new_entity)
             new_entity.merge(popped_entity)
         # Add to outputs
-        payload = {new_entity.get_qualified_name(): new_entity}
+        payload = {new_entity.qualifiedName: new_entity}
         column_entities.update(payload)
 
         return _qual_name
@@ -337,16 +338,15 @@ class LineageMixIn():
                 table_process = reader_util.first_process_containing_io(
                     "*", row[target_header["table"]], atlas_entities)
 
-            if table_process.get_name() in table_and_proc_mappings:
-                process_type = table_and_proc_mappings[table_process.get_name(
-                )]["column_lineage_type"]
+            if table_process.name in table_and_proc_mappings:
+                process_type = table_and_proc_mappings[table_process.name]["column_lineage_type"]
             else:
                 process_type = reader_util.from_process_lookup_col_lineage(
-                    table_process.get_name(),
+                    table_process.name,
                     atlas_entities,
                     atlas_typedefs["relationshipDefs"]
                 )
-                table_and_proc_mappings[table_process.get_name()] = {
+                table_and_proc_mappings[table_process.name] = {
                     "column_lineage_type": process_type
                 }
 
@@ -362,7 +362,7 @@ class LineageMixIn():
                      })
 
             process_qual_name = (
-                table_process.get_name() +
+                table_process.name +
                 "@derived_column:{}".format(
                     row[target_header["column"]]
                 ))
@@ -373,7 +373,7 @@ class LineageMixIn():
                 columnEntitiesOutput[target_qual_name].to_json(minimum=True)]
 
             process_entity = AtlasProcess(
-                name=table_process.get_name(),
+                name=table_process.name,
                 typeName=process_type,
                 # qualifiedName can be overwritten via the
                 # attributes functionality
@@ -393,16 +393,16 @@ class LineageMixIn():
                 process_entity.merge(popped_entity)
             # Add to outputs
             columnEntitiesOutput.update(
-                {process_entity.get_qualified_name(): process_entity})
+                {process_entity.qualifiedName: process_entity})
 
             if use_column_mapping:
                 # Handles multiple source columns from multiple source datasets
                 col_map_source_col = (
                     "*" if source_qual_name is None
-                    else columnEntitiesOutput[source_qual_name].get_name()
+                    else columnEntitiesOutput[source_qual_name].name
                 )
                 col_map_target_col = (
-                    columnEntitiesOutput[target_qual_name].get_name()
+                    columnEntitiesOutput[target_qual_name].name
                 )
                 col_map_source_table = row[source_header["table"]] or "*"
                 col_map_target_table = row[target_header["table"]]
@@ -462,6 +462,9 @@ class LineageMixIn():
                         "uniqueAttributes": {"qualifiedName": qual_name}}]
         return results
 
+    def _header_qn(self, l):
+        return l["uniqueAttributes"]["qualifiedName"]
+
     def parse_update_lineage(self, json_rows):
         """
         Take in UpdateLineage dictionaries and create the mutated Process
@@ -486,6 +489,9 @@ class LineageMixIn():
         sp = self.config.source_prefix
         tp = self.config.target_prefix
         pp = self.config.process_prefix
+
+        processes_seen = dict()
+
         for row in json_rows:
             try:
                 target_type = row[f"{tp} typeName"]
@@ -504,14 +510,50 @@ class LineageMixIn():
                 source_qual_name, source_type)
             outputs = self._determine_dataset_to_use(
                 target_qual_name, target_type)
-            # Convert the target / source into
-            proc = AtlasProcess(
-                name=process_name,
-                typeName=process_type,
-                qualified_name=process_qual_name,
-                guid=self.guidTracker.get_guid(),
-                inputs=inputs,
-                outputs=outputs
-            )
-            results.append(proc.to_json())
+
+            if process_qual_name in processes_seen:
+                temp_proc = processes_seen[process_qual_name]
+                # Get the inputs and outputs as they exist before this row
+                temp_in = temp_proc.inputs
+                temp_out = temp_proc.outputs
+                # If we have an input, check if it already exists
+                if inputs and len(inputs) > 0:
+                    input_qn = self._header_qn(inputs[0])    
+                    if input_qn not in [self._header_qn(x) for x in temp_in]:
+                        temp_in.extend(inputs)
+                        temp_proc.inputs = temp_in
+                        
+                    else:
+                        warnings.warn(f"Input '{input_qn}' is repeated in Process '{process_qual_name}'. Only the earliest entry is kept.")
+                elif isinstance(inputs, list):
+                    # We have an empty list, as the input, meaning destroy the input
+                    if len(temp_in) > 0:
+                        warnings.warn(f"Process '{process_qual_name}' has conflicting inputs and N/A values and will possibly be overwritten.")
+                    temp_proc.inputs(inputs)
+
+                if outputs:
+                    output_qn = self._header_qn(outputs[0])    
+                    if output_qn not in [self._header_qn(x) for x in temp_out]:
+                        temp_out.extend(outputs)
+                        temp_proc.outputs = temp_out
+                    else:
+                        warnings.warn(f"Output '{output_qn}' is repeated in Process '{process_qual_name}'. Only the earliest entry is kept.")
+                elif isinstance(outputs, list):
+                    # We have an empty list, as the output, meaning destroy the output
+                    if len(temp_out) > 0:
+                        warnings.warn(f"Process '{process_qual_name}' has conflicting outputs and N/A values and will possibly be overwritten.")
+                    temp_proc.outputs = outputs
+                
+            else:
+                proc = AtlasProcess(
+                    name=process_name,
+                    typeName=process_type,
+                    qualified_name=process_qual_name,
+                    guid=self.guidTracker.get_guid(),
+                    inputs=inputs,
+                    outputs=outputs
+                )
+                processes_seen[process_qual_name] = proc
+            
+            results = [v.to_json() for v in processes_seen.values()]
         return results
